KeyboardAvoidingView

Struct KeyboardAvoidingView 

pub struct KeyboardAvoidingView {
    pub transform: Option<Arc<dyn Fn(f32) -> LayoutAdjustment + Send + Sync>>,
}
A view that automatically adjusts its layout when the system keyboard appears, changes its dimensions or disappears.

Fields

transform: Option<Arc<dyn Fn(f32) -> LayoutAdjustment + Send + Sync>>

Transformation function that should return a adjustment based on the keyboard’s height, that we apply to the layout of this view.