LayoutAdjustment

Struct LayoutAdjustment 

pub struct LayoutAdjustment { /* private fields */ }
Structure that contains all updates that should be made to a view’s layout in response to a change in the visibility or dimensions of the system’s virtual keyboard.

Implementations

Source

impl LayoutAdjustment

pub fn new() -> LayoutAdjustment

Returns a new and empty layout adjustment.

pub fn margin_bottom(self, bottom: Dimension<f32>) -> LayoutAdjustment

Sets the margin bottom of this layout adjustment. Note that this will be added to the existing margin of the view.