pub fn attributed_string(text: &str, style: &TextStyle) -> NSAttributedStringExpand description
Generates a new NSAttributedString for the given text with the given text
style.
pub fn attributed_string(text: &str, style: &TextStyle) -> NSAttributedStringGenerates a new NSAttributedString for the given text with the given text
style.