QueueBound

Struct QueueBound 

pub struct QueueBound<T>
where T: 'static,
{ /* private fields */ }
Wraps an object that is bound to a specific libdispatch DispatchQueue. As a result, the wrapped object can only be accessed from the specified queue and will always be dropped from that queue (regardless of which thread the wrapper is dropped by).

Implementations

Source

impl<T> QueueBound<T>
where T: 'static,

pub fn new<F>(queue: Queue, initializer: F) -> QueueBound<T>
where F: FnOnce() -> T + Send + 'static,

Returns a new queue bound wrapper around a value that is asynchronously initialized using the given closure. The given closure is executed on the given queue.

pub unsafe fn adopt(queue: Queue, value: T) -> QueueBound<T>

Adopts a value that is assumed to already live on the given queue.

pub fn with<F>(&self, task: F)
where F: FnOnce(&mut T) + Send + 'static,

Sends the given task to the queue and applies it to the value this instance wraps.

pub unsafe fn with_adopt<F, V>(&self, value: V, task: F)
where V: 'static, F: FnOnce(&mut T, V) + Send + 'static,

Sends the given task and a value that is assumed to already live on the this queue, to the queue and applies it to the value this instance wraps.