pub type View = View<Platform, ViewHandle>;Expand description
Specializes the generic View component with the iOS-specific concrete view handle.
Aliased Type
pub struct View {
pub style: ViewStyle,
pub on_pointer_cancel: EventListener<()>,
pub on_pointer_down: EventListener<()>,
pub on_pointer_up: EventListener<()>,
pub on_layout: EventListener<Size<f32>>,
pub reference: Option<WeakReference<Platform, Option<ViewHandle>>>,
}Fields
style: ViewStyleControls the appearance and layout of a View.
on_pointer_cancel: EventListener<()>Called when the user cancels pressing a View.
on_pointer_down: EventListener<()>Called when the user starts pressing a View.
on_pointer_up: EventListener<()>Called when the user stops pressing a View.
on_layout: EventListener<Size<f32>>Called when a View is layed out.
reference: Option<WeakReference<Platform, Option<ViewHandle>>>This is a reference to an imperative view handle that can be used to measure the dimensions of this view or schedule animations.