pub struct QueueBound<T>where
T: 'static,{ /* private fields */ }Expand description
Wraps an object that is bound to a specific libdispatch DispatchQueue. As a result, the wrapped object can only be accessed from the specified queue and will always be dropped from that queue (regardless of which thread the wrapper is dropped by).
Implementations
Sourceimpl<T> QueueBound<T>where
T: 'static,
impl<T> QueueBound<T>where
T: 'static,
Sourcepub fn new<F>(queue: Queue, initializer: F) -> QueueBound<T>
pub fn new<F>(queue: Queue, initializer: F) -> QueueBound<T>
Returns a new queue bound wrapper around a value that is asynchronously initialized using the given closure. The given closure is executed on the given queue.
Sourcepub unsafe fn adopt(queue: Queue, value: T) -> QueueBound<T>
pub unsafe fn adopt(queue: Queue, value: T) -> QueueBound<T>
Adopts a value that is assumed to already live on the given queue.
Sourcepub fn with<F>(&self, task: F)
pub fn with<F>(&self, task: F)
Sends the given task to the queue and applies it to the value this instance wraps.
Sourcepub unsafe fn with_adopt<F, V>(&self, value: V, task: F)
pub unsafe fn with_adopt<F, V>(&self, value: V, task: F)
Sends the given task and a value that is assumed to already live on the this queue, to the queue and applies it to the value this instance wraps.